@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '1.04';
+  $CPAN::Perl::Releases::VERSION = '1.06';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -323,6 +323,10 @@ our $data =
     "tar.bz2" => "R/RJ/RJBS/perl-5.16.3-RC1.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.16.3-RC1.tar.gz",
   },
+  "5.16.3" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.3.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.3.tar.gz",
+  },
   "5.17.0" => {
     "tar.bz2" => "Z/ZE/ZEFRAM/perl-5.17.0.tar.bz2",
     "tar.gz" => "Z/ZE/ZEFRAM/perl-5.17.0.tar.gz",
@@ -471,7 +475,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 1.04
+version 1.06
 
 =head1 SYNOPSIS
 
